// This file has been generated by Py++.

#ifndef OneWayDescriptorObject_hpp__pyplusplus_wrapper
#define OneWayDescriptorObject_hpp__pyplusplus_wrapper

void register_OneWayDescriptorObject_class();

#endif//OneWayDescriptorObject_hpp__pyplusplus_wrapper
